==> mgv-2.2.1.tar.gz: mgv-2.2.1/_switch_help.c <==
/*
 * Generated file, hands off!
 */
char *bld_switch_longhelp[] = {
"-aliaseps, -noaliaseps",
	"\tAnti-aliasing graphic images will often make the images look",
	"\tworse and increase the rendering time significantly; hence,",
	"\tthese switches are offered to give you finer control over when",
	"\tanti-aliasing is used.  These switches set the ``antialiasEPS''",
	"\tapplication resource.",
"-antialias, -noantialias",
	"\tEnable or disable anti-aliasing within Ghostscript; by default,",
	"\tanti-aliasing is enabled.  If anti-aliasing is enable, then the",
	"\tx11alpha device is used and Ghostscript will be run with the",
	"\t-dNOPLATFONTS switch; if anti-aliasing is disabled, then the x11",
	"\tdevice will be used.  This switch sets the ``antialias''",
	"\tresource for Ghostview widgets.",
"-arguments args",
	"\tSpecify additional arguments for Ghostscript; this switch sets",
	"\tthe ``arguments'' resource.",
"-autoheight, -noautoheight",
	"\tAttempt to make the main window tall enough to accomodate a",
	"\twhole page.  This switch sets the ``autoHeight'' resource.",
"-autowidth, -noautowidth",
	"\tAttempt to make the main window wide enough to accomodate a",
	"\twhole page.  This switch sets the ``autoWidth'' resource.",
"-browser htmlbrowser",
	"\tSpecify the HTML browser to use for the on-line help; this",
	"\tswitch sets the ``helpBrowser'' resource.",
"-color, -grayscale, -greyscale, -monochrome",
	"\tForce color/grayscale/monochrome display; these switches do not",
	"\thave anything to do with the visual, depth, or colormap that MGv",
	"\tuses, you will want to use the -visual, -visualid, -depth, and",
	"\t-privatecm switches for that.  These switches set the palette",
	"\tresource.",
"-coloricon, -monoicon, -nocoloricon",
	"\tUse or don't use a color icon (if available).  These switches",
	"\tset the ``wlUseColorIcon'' resource.",
"-confirmexit, -noconfirmexit",
	"\tRequire or don't require user confirmation when attempting to",
	"\texit the application with more than one top level viewing",
	"\twindow.  These switches set the ``confirmExit'' resource.",
"-decompress cmd",
	"\tSpecify the command to decompress compressed files; the command",
	"\tshould read from the standard input and write to the standard",
	"\toutput.  This switch sets the ``decompress'' resource.",
"-depth n",
	"\tSpecify a non-default color depth.  This switch sets the",
	"\t``wlDepth'' resource.",
"-dpi n, -resolution n",
	"\tSpecify the overall resolution; these switches set the",
	"\tResolution resource.",
"-gslocale locale",
	"\tForce the GHOSTVIEW window property to be written according to",
	"\tlocale.  This switch sets the ``gsLocale'' resource.",
"-help",
	"\tDisplay a short summary of the available command line switches.",
"-helpport port",
	"\tSpecify a non-default port to use for Mosaic/CCI on-line help.",
	"\tThis switch sets the ``helpCCIPort'' resource.",
"-helptype type",
	"\tSpecify the help type for on-line help.  This switch sets the",
	"\t``helpType'' resource to type.",
"-interpreter interp",
	"\tUse interp as the PostScript interpreter.  This switch is useful",
	"\tif you want to use an interpreter that is not in your PATH or is",
	"\tnot the first gs is your PATH.  This switch sets the",
	"\t``interpreter'' resource.",
"-killkids, -nokillkids",
	"\tKill or don't kill child processes when MGv exits; this switch",
	"\tsets the ``killChildrenAtExit'' resource.",
"-labels, -nolabels",
	"\tShow or don't show the page labels in the page list; this switch",
	"\tsets the ``showLabels'' resource.",
"-log, -nolog",
	"\tShow or hide the Ghostscript log on start-up; this switch sets",
	"\tthe ``hideLog'' resource.",
"-longhelp",
	"\tDisplay a summary, with explanations, of the available command",
	"\tline switches.",
"-magicresistance n",
	"\tSpecify the number of attempts to scroll beyond the page",
	"\tboundaries before magical scrolling takes effect; this switch",
	"\tsets the ``magicResistance'' resource.",
"-magicscroll, -nomagicscroll",
	"\tAllow or disallow magical scrolling; this switch sets the",
	"\t``magicScrolling'' resource.",
"-magstep m",
	"\tSet the initial magstep to m; this switch sets the ``magstep''",
	"\tresource.",
"-media media, -paper media",
	"\tSpecify the default page media; this switch sets the",
	"\t``defaultPageMedia'' resource.",
"-menubar, -nomenubar",
	"\tShow or hide the menu bar at start up; this switch sets the",
	"\t``hideMenuBar'' resource.",
"-pagelist, -nopagelist",
	"\tShow or hide the page list at start up; this switch sets the",
	"\t``hidePageList'' resource.",
"-pgnums, -nopgnums",
	"\tShow or don't show the page numbers in the page list; this",
	"\tresource sets the ``showPageNumbers'' resource.",
"-portrait, -landscape, -seascape, -upsidedown",
	"\tSpecify the initial page orientation.",
"-prefix pfx",
	"\tSpecify the location of the files for the on-line help; this",
	"\tswitch sets the ``helpPrefix'' resource.",
"-printcommand cmd",
	"\tUse cmd as the default printer command; this switch sets the",
	"\t``printCommand'' resource.",
"-printer name",
	"\tUse name as the default printer name; this switch sets the",
	"\t``printer'' resource.",
"-privatecm, -noinstall, -noprivatecm, -noinstall",
	"\tInstall or don't install a private colormap.  Non-default visual",
	"\tand/or depth settings may cause this switch to be ignored.  This",
	"\tswitch sets the ``wlUsePrivateColormap'' resource.",
"-quiet, -noquiet",
	"\tUse or don't use -dQUIET with Ghostscript; this switch sets the",
	"\tquiet resource.  The -dQUIET switch tells Ghostscript to",
	"\tsuppresses the normal startup messages.",
"-safer, -nosafer",
	"\tUse or don't use -dSAFER with Ghostscript; this switch sets the",
	"\tsafer resource.  When run with the -dSAFER switch, Ghostscript",
	"\tdisables the deletefile and renamefile operators and can only",
	"\topen files with read-only access.",
"-scrollpercent percentage",
	"\tScroll the screen by percentage of the window size when",
	"\tscrolling with the keyboard.  This switch sets the",
	"\t``scrollPercentage'' resource.",
"-smartsizing, -nosmartsizing",
	"\tEnable or disable smart sizing.  This switch sets the",
	"\t``smartSizing'' resource.",
"-smooth, -nosmooth",
	"\tEnable or disable smooth scrolling.  This switch sets the",
	"\t``smoothScrolling'' resource.",
"-smoothness n",
	"\tSpecify how smooth smooth scrolling should be.  This switch sets",
	"\tthe ``smoothness'' resource to n.",
"-status, -nostatus",
	"\tShow or hide the status line at start up; this switch sets the",
	"\t``hideStatusLine'' resource.",
"-temp dir",
	"\tSpecify the temporary directory; this switch sets the",
	"\t``tempDir'' resource.",
"-version",
	"\tDisplay lots of version and build information about MGv.  The",
	"\tdisplayed information is the same as that in the ``Build Options",
	"\tDialog''.",
"-visual visualClass",
	"\tSpecify a non-default visual.  This switch sets the",
	"\t``wlVisualClass'' resource.",
"-visualid visualID",
	"\tSpecify a non-default visual by visual id (see xdpyinfo for a",
	"\tlist of visual ids).  This switch sets the ``wlVisualID''",
	"\tresource.",
"-wmwidth width, -wmheight height",
	"\tSet the total width or height of the window manager decorations.",
	"\tThese switches set the ``wmWidth'' and ``wmHeight'' resources.",
"-xdpi n, -ypdi n",
	"\tSpecify the horizontal and vertical resolutions; these switches",
	"\tset the xdpi and ydpi resources.",
"-zoomfg color, -reticulefg color",
	"\tSpecify the zoom reticule color; these switches set the",
	"\t``reticuleForeground'' resource.",
"-zoomwidth n, -reticulewidth n",
	"\tSpecify the zoom reticule width; these switches set the",
	"\t``reticuleLineWidth'' resource.",
(char *)0
};

char *bld_switch_help[] = {
"[-help]",
"[-longhelp]",
"[-[no]aliaseps]",
"[-[no]antialias]",
"[-[no]autoheight]",
"[-[no]autowidth]",
"[-[no]confirmexit]",
"[-[no]killkids]",
"[-[no]labels]",
"[-[no]log]",
"[-[no]magicscroll]",
"[-[no]menubar]",
"[-[no]pagelist]",
"[-[no]pgnums]",
"[-[no]quiet]",
"[-[no]safer]",
"[-[no]smartsizing]",
"[-[no]smooth]",
"[-[no]status]",
"[-arguments args]",
"[-browser htmlbrowser]",
"[-color]",
"[-coloricon]",
"[-decompress cmd]",
"[-depth n]",
"[-dpi n]",
"[-grayscale]",
"[-greyscale]",
"[-gslocale locale]",
"[-helpport port]",
"[-helptype type]",
"[-interpreter interp]",
"[-landscape]",
"[-magicresistance n]",
"[-magstep m]",
"[-media media]",
"[-monochrome]",
"[-monoicon]",
"[-nocoloricon]",
"[-noinstall]",
"[-noinstall]",
"[-noprivatecm]",
"[-paper media]",
"[-portrait]",
"[-prefix pfx]",
"[-printcommand cmd]",
"[-printer name]",
"[-privatecm]",
"[-resolution n]",
"[-reticulefg color]",
"[-reticulewidth n]",
"[-scrollpercent percentage]",
"[-seascape]",
"[-smoothness n]",
"[-temp dir]",
"[-upsidedown]",
"[-version]",
"[-visual visualClass]",
"[-visualid visualID]",
"[-wmheight height]",
"[-wmwidth width]",
"[-xdpi n]",
"[-ypdi n]",
"[-zoomfg color]",
"[-zoomwidth n]",
(char *)0
};

==> mgv-2.4.2.tar.gz: mgv-2.4.2/_switch_help.c <==
/*
 * Generated file, hands off!
 */
char *bld_switch_longhelp[] = {
"-aliaseps, -noaliaseps",
	"\tAnti-aliasing graphic images will often make the images look",
	"\tworse and increase the rendering time significantly; hence,",
	"\tthese switches are offered to give you finer control over when",
	"\tanti-aliasing is used.  These switches set the ``antialiasEPS''",
	"\tapplication resource.",
"-antialias, -noantialias",
	"\tEnable or disable anti-aliasing within Ghostscript; by default,",
	"\tanti-aliasing is enabled.  If anti-aliasing is enable, then the",
	"\tx11alpha device is used and Ghostscript will be run with the",
	"\t-dNOPLATFONTS switch; if anti-aliasing is disabled, then the x11",
	"\tdevice will be used.  This switch sets the ``antialias''",
	"\tresource for Ghostview widgets.",
"-arguments args",
	"\tSpecify additional arguments for Ghostscript; this switch sets",
	"\tthe ``arguments'' resource.",
"-autoheight, -noautoheight",
	"\tAttempt to make the main window tall enough to accomodate a",
	"\twhole page.  This switch sets the ``autoHeight'' resource.",
"-autowidth, -noautowidth",
	"\tAttempt to make the main window wide enough to accomodate a",
	"\twhole page.  This switch sets the ``autoWidth'' resource.",
"-browser htmlbrowser",
	"\tSpecify the HTML browser to use for the on-line help; this",
	"\tswitch sets the ``helpBrowser'' resource.",
"-bunzip cmd",
	"\tSpecify the command to decompress bzip2ed files; the command",
	"\tshould read from the standard input and write to the standard",
	"\toutput.  This switch sets the ``bunzip'' resource.",
"-bzip cmd",
	"\tSpecify the command to compress files with bzip2.  This switch",
	"\tsets the ``bzip'' resource.",
"-color, -grayscale, -greyscale, -monochrome",
	"\tForce color/grayscale/monochrome display; these switches do not",
	"\thave anything to do with the visual, depth, or colormap that MGv",
	"\tuses, you will want to use the -visual, -visualid, -depth, and",
	"\t-privatecm switches for that.  These switches set the palette",
	"\tresource.",
"-coloricon, -monoicon, -nocoloricon",
	"\tUse or don't use a color icon (if available).  These switches",
	"\tset the ``wlUseColorIcon'' resource.",
"-compress cmd",
	"\tSpecify the command to compress files with compress.  This",
	"\tswitch sets the ``compress'' resource.",
"-confirmexit, -noconfirmexit",
	"\tRequire or don't require user confirmation when attempting to",
	"\texit the application with more than one top level viewing",
	"\twindow.  These switches set the ``confirmExit'' resource.",
"-copystdin, -nocopystdin",
	"\tCopy or don't copy files from the standard input to a temporary",
	"\tfile.  These switches set the ``copyStdin'' resource.",
"-decompress cmd",
	"\tSpecify the command to decompress compressed files; the command",
	"\tshould read from the standard input and write to the standard",
	"\toutput.  This switch sets the ``decompress'' resource.  This",
	"\tswitch is an alias for -gunzip.",
"-depth n",
	"\tSpecify a non-default color depth.  This switch sets the",
	"\t``wlDepth'' resource.",
"-dpi n, -resolution n",
	"\tSpecify the overall resolution; these switches set the",
	"\tResolution resource.",
"-editres, -noeditres",
	"\tInstall or don't install support for editres.  This switch sets",
	"\tthe ``wlUseEditRes'' resource.",
"-gslocale locale",
	"\tForce the GHOSTVIEW window property to be written according to",
	"\tlocale.  This switch sets the ``gsLocale'' resource.",
"-gunzip cmd",
	"\tSpecify the command to decompress compressed files; the command",
	"\tshould read from the standard input and write to the standard",
	"\toutput.  This switch sets the ``gunzip'' resource.",
"-gzip cmd",
	"\tSpecify the command to compress files with gzip.  This switch",
	"\tsets the ``gzip'' resource.",
"-help",
	"\tDisplay a short summary of the available command line switches.",
"-helpport port",
	"\tSpecify a non-default port to use for Mosaic/CCI on-line help.",
	"\tThis switch sets the ``helpCCIPort'' resource.",
"-helptype type",
	"\tSpecify the help type for on-line help.  This switch sets the",
	"\t``helpType'' resource to type.",
"-installicon, -noicon",
	"\tInstall or don't install an icon when the application starts up.",
	"\tThese switches set the ``wlInstallIcon'' resource.",
"-interpreter interp",
	"\tUse interp as the PostScript interpreter.  This switch is useful",
	"\tif you want to use an interpreter that is not in your PATH or is",
	"\tnot the first gs is your PATH.  This switch sets the",
	"\t``interpreter'' resource.",
"-killkids, -nokillkids",
	"\tKill or don't kill child processes when MGv exits; this switch",
	"\tsets the ``killChildrenAtExit'' resource.",
"-labels, -nolabels",
	"\tShow or don't show the page labels in the page list; this switch",
	"\tsets the ``showLabels'' resource.",
"-log, -nolog",
	"\tShow or hide the Ghostscript log on start-up; this switch sets",
	"\tthe ``hideLog'' resource.",
"-longhelp",
	"\tDisplay a summary, with explanations, of the available command",
	"\tline switches.",
"-magicresistance n",
	"\tSpecify the number of attempts to scroll beyond the page",
	"\tboundaries before magical scrolling takes effect; this switch",
	"\tsets the ``magicResistance'' resource.",
"-magicscroll, -nomagicscroll",
	"\tAllow or disallow magical scrolling; this switch sets the",
	"\t``magicScrolling'' resource.",
"-magstep m",
	"\tSet the initial magstep to m; this switch sets the ``magstep''",
	"\tresource.",
"-media media, -paper media",
	"\tSpecify the default page media; this switch sets the",
	"\t``defaultPageMedia'' resource.",
"-menubar, -nomenubar",
	"\tShow or hide the menu bar at start up; this switch sets the",
	"\t``hideMenuBar'' resource.",
"-pagelist, -nopagelist",
	"\tShow or hide the page list at start up; this switch sets the",
	"\t``hidePageList'' resource.",
"-pgnums, -nopgnums",
	"\tShow or don't show the page numbers in the page list; this",
	"\tresource sets the ``showPageNumbers'' resource.",
"-portrait, -landscape, -seascape, -upsidedown",
	"\tSpecify the initial page orientation.",
"-prefix pfx",
	"\tSpecify the location of the files for the on-line help; this",
	"\tswitch sets the ``helpPrefix'' resource.",
"-printcommand cmd",
	"\tUse cmd as the default printer command; this switch sets the",
	"\t``printCommand'' resource.",
"-printer name",
	"\tUse name as the default printer name; this switch sets the",
	"\t``printer'' resource.",
"-privatecm, -noinstall, -noprivatecm, -noinstall",
	"\tInstall or don't install a private colormap.  Non-default visual",
	"\tand/or depth settings may cause this switch to be ignored.  This",
	"\tswitch sets the ``wlUsePrivateColormap'' resource.",
"-quiet, -noquiet",
	"\tUse or don't use -dQUIET with Ghostscript; this switch sets the",
	"\tquiet resource.  The -dQUIET switch tells Ghostscript to",
	"\tsuppresses the normal startup messages.",
"-resetboth",
	"\tReset both the horizontal and vertical scrollbars when you move",
	"\tto a new page.  This switch sets the ``resetScrollBars''",
	"\tresource to both.",
"-resethor",
	"\tReset the horizontal scrollbar when you move to a new page.",
	"\tThis switch sets the ``resetScrollBars'' resource to horizontal.",
"-resetnone",
	"\tDon't reset either scrollbar when you move to a new page.  This",
	"\tswitch sets the ``resetScrollBars'' resource to none.",
"-resetver",
	"\tReset the vertical scrollbar when you move to a new page.  This",
	"\tswitch sets the ``resetScrollBars'' resource to vertical.",
"-safer, -nosafer",
	"\tUse or don't use -dSAFER with Ghostscript; this switch sets the",
	"\tsafer resource.  When run with the -dSAFER switch, Ghostscript",
	"\tdisables the deletefile and renamefile operators and can only",
	"\topen files with read-only access.",
"-scrollpercent percentage",
	"\tScroll the screen by percentage of the window size when",
	"\tscrolling with the keyboard.  This switch sets the",
	"\t``scrollPercentage'' resource.",
"-smartsizing, -nosmartsizing",
	"\tEnable or disable smart sizing.  This switch sets the",
	"\t``smartSizing'' resource.",
"-smooth, -nosmooth",
	"\tEnable or disable smooth scrolling.  This switch sets the",
	"\t``smoothScrolling'' resource.",
"-smoothness n",
	"\tSpecify how smooth smooth scrolling should be.  This switch sets",
	"\tthe ``smoothness'' resource to n.",
"-status, -nostatus",
	"\tShow or hide the status line at start up; this switch sets the",
	"\t``hideStatusLine'' resource.",
"-temp dir",
	"\tSpecify the temporary directory; this switch sets the",
	"\t``tempDir'' resource.",
"-version",
	"\tDisplay lots of version and build information about MGv.  The",
	"\tdisplayed information is the same as that in the ``Build Options",
	"\tDialog''.",
"-visual visualClass",
	"\tSpecify a non-default visual.  This switch sets the",
	"\t``wlVisualClass'' resource.",
"-visualid visualID",
	"\tSpecify a non-default visual by visual id (see xdpyinfo for a",
	"\tlist of visual ids).  This switch sets the ``wlVisualID''",
	"\tresource.",
"-wmwidth width, -wmheight height",
	"\tSet the total width or height of the window manager decorations.",
	"\tThese switches set the ``wmWidth'' and ``wmHeight'' resources.",
"-xdpi n, -ypdi n",
	"\tSpecify the horizontal and vertical resolutions; these switches",
	"\tset the xdpi and ydpi resources.",
"-zoomfg color, -reticulefg color",
	"\tSpecify the zoom reticule color; these switches set the",
	"\t``reticuleForeground'' resource.",
"-zoomwidth n, -reticulewidth n",
	"\tSpecify the zoom reticule width; these switches set the",
	"\t``reticuleLineWidth'' resource.",
(char *)0
};

char *bld_switch_help[] = {
"[-help]",
"[-longhelp]",
"[-[no]aliaseps]",
"[-[no]antialias]",
"[-[no]autoheight]",
"[-[no]autowidth]",
"[-[no]confirmexit]",
"[-[no]copystdin]",
"[-[no]editres]",
"[-[no]killkids]",
"[-[no]labels]",
"[-[no]log]",
"[-[no]magicscroll]",
"[-[no]menubar]",
"[-[no]pagelist]",
"[-[no]pgnums]",
"[-[no]quiet]",
"[-[no]safer]",
"[-[no]smartsizing]",
"[-[no]smooth]",
"[-[no]status]",
"[-arguments args]",
"[-browser htmlbrowser]",
"[-bunzip cmd]",
"[-bzip cmd]",
"[-color]",
"[-coloricon]",
"[-compress cmd]",
"[-decompress cmd]",
"[-depth n]",
"[-dpi n]",
"[-grayscale]",
"[-greyscale]",
"[-gslocale locale]",
"[-gunzip cmd]",
"[-gzip cmd]",
"[-helpport port]",
"[-helptype type]",
"[-installicon]",
"[-interpreter interp]",
"[-landscape]",
"[-magicresistance n]",
"[-magstep m]",
"[-media media]",
"[-monochrome]",
"[-monoicon]",
"[-nocoloricon]",
"[-noicon]",
"[-noinstall]",
"[-noinstall]",
"[-noprivatecm]",
"[-paper media]",
"[-portrait]",
"[-prefix pfx]",
"[-printcommand cmd]",
"[-printer name]",
"[-privatecm]",
"[-resetboth]",
"[-resethor]",
"[-resetnone]",
"[-resetver]",
"[-resolution n]",
"[-reticulefg color]",
"[-reticulewidth n]",
"[-scrollpercent percentage]",
"[-seascape]",
"[-smoothness n]",
"[-temp dir]",
"[-upsidedown]",
"[-version]",
"[-visual visualClass]",
"[-visualid visualID]",
"[-wmheight height]",
"[-wmwidth width]",
"[-xdpi n]",
"[-ypdi n]",
"[-zoomfg color]",
"[-zoomwidth n]",
(char *)0
};
